@@ -19,6 +19,7 @@ from acconeer.exptool.a121._core.entities import (
     SensorConfig,
     SensorInfo,
     ServerInfo,
+    ServerLogMessage,
     SessionConfig,
 )
 from acconeer.exptool.a121._core.utils import (
@@ -62,6 +63,7 @@ class AgnosticClient(AgnosticClientFriends):
     _system_info: Optional[SystemInfoDict]
     _result_queue: list[list[dict[int, Result]]]
     _message_stream: Iterator[Message]
+    _log_queue: list[ServerLogMessage]
 
     def __init__(self, link: BufferedLink, protocol: Type[CommunicationProtocol]) -> None:
         self._link = link
@@ -79,17 +81,18 @@ class AgnosticClient(AgnosticClientFriends):
         self._sensor_infos = {}
         self._system_info = None
         self._result_queue = []
+        self._log_queue = []
 
-    def _assert_connected(self):
+    def _assert_connected(self) -> None:
         if not self.connected:
             raise ClientError("Client is not connected.")
 
-    def _assert_session_setup(self):
+    def _assert_session_setup(self) -> None:
         self._assert_connected()
         if not self.session_is_setup:
             raise ClientError("Session is not set up.")
 
-    def _assert_session_started(self):
+    def _assert_session_started(self) -> None:
         self._assert_session_setup()
         if not self.session_is_started:
             raise ClientError("Session is not started.")
@@ -251,8 +254,11 @@ class AgnosticClient(AgnosticClientFriends):
         pc = _SessionPerformanceCalc(config, self._metadata)
 
         try:
+            # Use max of the calculate duration and update/frame rate to guarantee sufficient
+            # timeout.
+            timeout_duration = max(pc.update_duration, 1 / pc.update_rate)
             # Increase timeout if update rate is very low, otherwise keep default
-            self._link_timeout = max(1.5 * (1 / pc.update_rate) + 1.0, self._default_link_timeout)
+            self._link_timeout = max(1.5 * timeout_duration + 1.0, self._default_link_timeout)
         except Exception:
             self._link_timeout = self._default_link_timeout
 
@@ -358,6 +364,7 @@ class AgnosticClient(AgnosticClientFriends):
             self._recorder = None
 
         self._rate_stats_calc = None
+        self._log_queue.clear()
 
         return recorder_result
 
@@ -374,13 +381,14 @@ class AgnosticClient(AgnosticClientFriends):
         self._sensor_infos = {}
         self._message_stream = iter([])
         self._metadata = None
+        self._log_queue.clear()
         self._link.disconnect()
 
-    def __enter__(self):
+    def __enter__(self) -> AgnosticClient:
         self.connect()
         return self
 
-    def __exit__(self, type_, value, traceback):
+    def __exit__(self, *_: Any) -> None:
         self.disconnect()
 
     @property
