@@ -5,7 +5,7 @@ from __future__ import annotations
 
 import abc
 from pathlib import Path
-from typing import Callable, Dict, Generic, List, Optional, Type
+from typing import Callable, Dict, Generic, List, Mapping, Optional, Type
 
 import attrs
 import h5py
@@ -39,6 +39,12 @@ DATA_SATURATED_MESSAGE = "Data saturated - reduce gain"
 FRAME_DELAYED_MESSAGE = "Frame delayed"
 
 
+@attrs.mutable(kw_only=True)
+class ProcessorPluginPreset(Generic[ConfigT]):
+    session_config: a121.SessionConfig = attrs.field()
+    processor_config: ConfigT = attrs.field()
+
+
 @attrs.mutable(kw_only=True)
 class ProcessorBackendPluginSharedState(Generic[ConfigT, MetadataT]):
     session_config: a121.SessionConfig = attrs.field()
@@ -47,7 +53,7 @@ class ProcessorBackendPluginSharedState(Generic[ConfigT, MetadataT]):
     metadata: Optional[MetadataT] = attrs.field(default=None)
 
     @property
-    def ready(self):
+    def ready(self) -> bool:
         try:
             self.session_config.validate()
         except a121.ValidationError:
@@ -68,6 +74,8 @@ class GenericProcessorBackendPluginBase(
     _opened_record: Optional[a121.H5Record]
     _replaying_client: Optional[a121._ReplayingClient]
 
+    PLUGIN_PRESETS: Mapping[int, Callable[[], ProcessorPluginPreset]] = {}
+
     def __init__(
         self, callback: Callable[[Message], None], generation: PluginGeneration, key: str
     ):
@@ -322,6 +330,14 @@ class ProcessorBackendPluginBase(
 
         self.broadcast(sync=True)
 
+    @is_task
+    def set_preset(self, preset_id: int) -> None:
+        preset_config = self.PLUGIN_PRESETS[preset_id]
+        processor_preset = preset_config()
+        self.shared_state.session_config = processor_preset.session_config
+        self.shared_state.processor_config = processor_preset.processor_config
+        self.broadcast(sync=True)
+
     def _get_next(self) -> None:
         if self._client is None:
             raise RuntimeError("Client is not attached. Can not 'get_next'.")
