@@ -47,6 +47,7 @@ class DetectorStatus:
 
 class DetailedStatus(enum.Enum):
     OK = enum.auto()
+    END_LESSER_THAN_START = enum.auto()
     SENSOR_IDS_NOT_UNIQUE = enum.auto()
     CONTEXT_MISSING = enum.auto()
     CALIBRATION_MISSING = enum.auto()
@@ -532,6 +533,12 @@ class Detector:
                 ready_to_start=False,
             )
 
+        if config.end_m < config.start_m:
+            return DetectorStatus(
+                detector_state=DetailedStatus.END_LESSER_THAN_START,
+                ready_to_start=False,
+            )
+
         if len(sensor_ids) != len(set(sensor_ids)):
             return DetectorStatus(
                 detector_state=DetailedStatus.SENSOR_IDS_NOT_UNIQUE,
