@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+from enum import Enum, auto
 from typing import Callable, Type
 
 import numpy as np
@@ -16,6 +17,7 @@ from acconeer.exptool import a121
 from acconeer.exptool.a121.algo._plugins import (
     ProcessorBackendPluginBase,
     ProcessorPlotPluginBase,
+    ProcessorPluginPreset,
     ProcessorViewPluginBase,
 )
 from acconeer.exptool.a121.algo._utils import APPROX_BASE_STEP_LENGTH_M
@@ -30,12 +32,25 @@ from acconeer.exptool.app.new import (
     Message,
     PluginFamily,
     PluginGeneration,
+    PluginPresetBase,
     PluginSpecBase,
 )
 from acconeer.exptool.app.new.ui.plugin_components import PidgetFactoryMapping, pidgets
 
 
+class PluginPresetId(Enum):
+    DEFAULT = auto()
+
+
 class BackendPlugin(ProcessorBackendPluginBase[ProcessorConfig, ProcessorResult]):
+
+    PLUGIN_PRESETS = {
+        PluginPresetId.DEFAULT.value: lambda: ProcessorPluginPreset(
+            session_config=a121.SessionConfig(get_sensor_config()),
+            processor_config=BackendPlugin.get_processor_config_cls()(),
+        ),
+    }
+
     @classmethod
     def get_processor_cls(cls) -> Type[Processor]:
         return Processor
@@ -64,6 +79,12 @@ class ViewPlugin(ProcessorViewPluginBase[ProcessorConfig]):
                 limits=(0, 1),
                 decimals=2,
             ),
+            "sensitivity": pidgets.FloatSliderParameterWidgetFactory(
+                name_label_text="Threshold sensitivity",
+                suffix="dB",
+                limits=(0, 30),
+                decimals=1,
+            ),
         }
 
     @classmethod
@@ -81,9 +102,10 @@ class PlotPlugin(ProcessorPlotPluginBase[ProcessorResult]):
 
         pen = et.utils.pg_pen_cycler(0)
         brush = et.utils.pg_brush_cycler(0)
+        brush_dot = et.utils.pg_brush_cycler(1)
         symbol_kw = dict(symbol="o", symbolSize=1, symbolBrush=brush, symbolPen="k")
         feat_kw = dict(pen=pen, **symbol_kw)
-        symbol_dot_kw = dict(symbol="o", symbolSize=10, symbolBrush=brush, symbolPen="k")
+        symbol_dot_kw = dict(symbol="o", symbolSize=10, symbolBrush=brush_dot, symbolPen="k")
 
         # precense plot
         self.precense_plot = pg.PlotItem()
@@ -117,7 +139,17 @@ class PlotPlugin(ProcessorPlotPluginBase[ProcessorResult]):
         self.fft_plot.setLabel("left", "Power (dB)")
         self.fft_plot.setLabel("bottom", "Frequency (Hz)")
         self.fft_plot.addItem(pg.PlotDataItem())
-        self.fft_curve = self.fft_plot.plot(**feat_kw)
+        self.fft_curve = [
+            self.fft_plot.plot(**feat_kw),
+            self.fft_plot.plot(**dict(pen=pen, **symbol_dot_kw)),
+        ]
+
+        self.text_item = pg.TextItem(
+            fill=pg.mkColor(0xFF, 0x7F, 0x0E, 200),
+            anchor=(0.5, 0),
+        )
+        self.text_item.hide()
+        self.fft_plot.addItem(self.text_item)
 
         self.smooth_max_fft = et.utils.SmoothMax()
 
@@ -127,6 +159,8 @@ class PlotPlugin(ProcessorPlotPluginBase[ProcessorResult]):
         z_abs_db = processor_result.lp_z_abs_db
         freqs = processor_result.freqs
         max_amplitude = processor_result.max_amplitude
+        max_psd_ampl = processor_result.max_psd_ampl
+        max_psd_ampl_freq = processor_result.max_psd_ampl_freq
 
         self.precense_curve.setData([self.meas_dist_m], [max_amplitude])
         lim = self.smooth_max_precense.update(max_amplitude)
@@ -136,10 +170,25 @@ class PlotPlugin(ProcessorPlotPluginBase[ProcessorResult]):
         lim = self.smooth_lim_time_series.update(time_series)
         self.time_series_plot.setYRange(lim[0], lim[1])
 
-        self.fft_curve.setData(freqs, z_abs_db)
+        self.fft_curve[0].setData(freqs, z_abs_db)
         lim = self.smooth_max_fft.update(np.max(z_abs_db))
         self.fft_plot.setYRange(0, lim)
 
+        if max_psd_ampl_freq is not None:
+            self.fft_curve[1].setData([max_psd_ampl_freq], [max_psd_ampl])
+            # Place text box centered at the top of the plotting window.
+            self.text_item.setPos(max(freqs) / 2, lim * 0.95)
+            html_format = (
+                '<div style="text-align: center">'
+                '<span style="color: #FFFFFF;font-size:15pt;">'
+                "{}</span></div>".format("Detected Frequency: " + str(int(max_psd_ampl_freq)))
+            )
+            self.text_item.setHtml(html_format)
+            self.text_item.show()
+        else:
+            self.fft_curve[1].setData([], [])
+            self.text_item.hide()
+
 
 class PluginSpec(PluginSpecBase):
     def create_backend_plugin(
@@ -162,4 +211,8 @@ VIBRATION_PLUGIN = PluginSpec(
     title="Vibration measurement",
     description="Quantify the frequency content of vibrating object.",
     family=PluginFamily.EXAMPLE_APP,
+    presets=[
+        PluginPresetBase(name="Default", preset_id=PluginPresetId.DEFAULT),
+    ],
+    default_preset_id=PluginPresetId.DEFAULT,
 )
