@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+from enum import Enum, auto
 from typing import Callable, Type
 
 import numpy as np
@@ -16,25 +17,47 @@ from acconeer.exptool import a121
 from acconeer.exptool.a121.algo._plugins import (
     ProcessorBackendPluginBase,
     ProcessorPlotPluginBase,
+    ProcessorPluginPreset,
     ProcessorViewPluginBase,
 )
 from acconeer.exptool.a121.algo.virtual_button import (
     Processor,
     ProcessorConfig,
     ProcessorResult,
-    get_near_sensor_config,
+    get_close_and_far_processor_config,
+    get_close_and_far_sensor_config,
+    get_close_processor_config,
+    get_close_sensor_config,
 )
 from acconeer.exptool.app.new import (
     AppModel,
     Message,
     PluginFamily,
     PluginGeneration,
+    PluginPresetBase,
     PluginSpecBase,
 )
 from acconeer.exptool.app.new.ui.plugin_components import PidgetFactoryMapping, pidgets
 
 
+class PluginPresetId(Enum):
+    CLOSE_RANGE = auto()
+    CLOSE_AND_FAR_RANGE = auto()
+
+
 class BackendPlugin(ProcessorBackendPluginBase[ProcessorConfig, ProcessorResult]):
+
+    PLUGIN_PRESETS = {
+        PluginPresetId.CLOSE_RANGE.value: lambda: ProcessorPluginPreset(
+            session_config=a121.SessionConfig(get_close_sensor_config()),
+            processor_config=get_close_processor_config(),
+        ),
+        PluginPresetId.CLOSE_AND_FAR_RANGE.value: lambda: ProcessorPluginPreset(
+            session_config=a121.SessionConfig(get_close_and_far_sensor_config()),
+            processor_config=get_close_and_far_processor_config(),
+        ),
+    }
+
     @classmethod
     def get_processor_cls(cls) -> Type[Processor]:
         return Processor
@@ -45,7 +68,7 @@ class BackendPlugin(ProcessorBackendPluginBase[ProcessorConfig, ProcessorResult]
 
     @classmethod
     def get_default_sensor_config(cls) -> a121.SensorConfig:
-        return get_near_sensor_config()
+        return get_close_sensor_config()
 
 
 class ViewPlugin(ProcessorViewPluginBase[ProcessorConfig]):
@@ -174,4 +197,17 @@ VIRTUAL_BUTTON_PLUGIN = PluginSpec(
     title="Virtual button",
     description="Detect tap/wave motion and register as button press.",
     family=PluginFamily.EXAMPLE_APP,
+    presets=[
+        PluginPresetBase(
+            name="Close Range",
+            description="Close range virtual button",
+            preset_id=PluginPresetId.CLOSE_RANGE,
+        ),
+        PluginPresetBase(
+            name="Close and far range",
+            description="Close and far range virtual button",
+            preset_id=PluginPresetId.CLOSE_AND_FAR_RANGE,
+        ),
+    ],
+    default_preset_id=PluginPresetId.CLOSE_RANGE,
 )
