@@ -84,6 +84,8 @@ class _FlashThread(QThread):
 
 
 class _FlashDialog(QDialog):
+    flash_done = Signal()
+
     def __init__(self, parent: QWidget) -> None:
         super().__init__(parent)
 
@@ -111,7 +113,7 @@ class _FlashDialog(QDialog):
 
         self.setLayout(vbox)
 
-    def flash(self, bin_file, flash_port):
+    def flash(self, bin_file: str, flash_port: serial.tools.list_ports.ListPortInfo) -> None:
         self.flash_thread = _FlashThread(bin_file, flash_port)
         self.flash_thread.started.connect(self._flash_start)
         self.flash_thread.finished.connect(self.flash_thread.deleteLater)
@@ -134,9 +136,11 @@ class _FlashDialog(QDialog):
         self._flashing = False
 
     def _flash_done(self) -> None:
+        self.flash_done.emit()
         self.flash_label.setText("Flashing done!")
 
     def _flash_failed(self, exception: Exception, traceback_str: Optional[str]) -> None:
+        self.flash_done.emit()
         self.flash_label.setText("Flashing failed!")
         ExceptionWidget(self, exc=exception, traceback_str=traceback_str).exec()
 
@@ -156,7 +160,7 @@ class _FlashPopup(QDialog):
         self.setWindowTitle("Flash tool")
         self.setMinimumWidth(550)
 
-        self.bin_file = None
+        self.bin_file: Optional[str] = None
 
         self.authenticating = False
         self.downloading_firmware = False
@@ -235,6 +239,7 @@ class _FlashPopup(QDialog):
         self.browse_file_dialog.setNameFilter("Bin files (*.bin)")
 
         self.flash_dialog = _FlashDialog(self)
+        self.flash_dialog.flash_done.connect(self._flash_done)
 
         app_model.sig_notify.connect(self._on_app_model_update)
 
@@ -345,30 +350,36 @@ class _FlashPopup(QDialog):
         self.adjustSize()
 
     def _flash(self) -> None:
-        flash_port = find_flash_port(self.flash_port, do_log=False)
+        flash_port = find_flash_port(
+            self.flash_port, do_log=False, use_serial=not isinstance(self.flash_port, USBDevice)
+        )
 
-        # TODO: disable autoconnect when flashing
+        assert self.bin_file is not None
+
+        self.app_model.set_port_updates_pause(True)
         self.flash_dialog.flash(self.bin_file, flash_port)
 
+    def _flash_done(self) -> None:
+        self.app_model.set_port_updates_pause(False)
+
     def _on_interface_dd_change(self) -> None:
         self.app_model.set_connection_interface(self.interface_dd.currentData())
 
     def _on_app_model_update(self, app_model: AppModel) -> None:
-        interface_index = 0
         if app_model.connection_interface in [ConnectionInterface.SERIAL, ConnectionInterface.USB]:
             interface_index = self.interface_dd.findData(app_model.connection_interface)
             if interface_index == -1:
                 raise RuntimeError
 
-        self.interface_dd.setCurrentIndex(interface_index)
-        self.stacked.setCurrentIndex(interface_index)
+            self.interface_dd.setCurrentIndex(interface_index)
+            self.stacked.setCurrentIndex(interface_index)
 
-        enable_select = (
-            find_flash_port(do_log=False) is not None
-            and not self.authenticating
-            and not self.downloading_firmware
-        )
-        self.get_latest_button.setEnabled(enable_select)
+            enable_select = (
+                find_flash_port(do_log=False) is not None
+                and not self.authenticating
+                and not self.downloading_firmware
+            )
+            self.get_latest_button.setEnabled(enable_select)
 
         self._draw()
 
@@ -379,7 +390,7 @@ class _FlashPopup(QDialog):
 
     def exec(self) -> None:
         if self.app_model.connection_interface == ConnectionInterface.SOCKET:
-            self.app_model.set_connection_interface(ConnectionInterface.SERIAL)
+            self.app_model.set_connection_interface(ConnectionInterface.USB)
 
         super().exec()
 
@@ -671,7 +682,6 @@ class BinDownloadThread(QThread):
                     temp_file, version = download(
                         session=self.session,
                         cookies=self.cookies,
-                        page=self.response,
                         path=temp_dir,
                         device=self.device,
                     )
