@@ -44,6 +44,8 @@ class USBDevice:
     pid: int
     serial: Optional[str] = None
     name: str
+    accessible: bool = True
+    unflashed: bool = False
 
     def to_dict(self) -> dict[str, Any]:
         return attrs.asdict(self)
@@ -59,14 +61,26 @@ class USBDevice:
     def from_json(cls, json_str: str) -> USBDevice:
         return cls.from_dict(json.loads(json_str))
 
+    def display_name(self) -> str:
+        if not self.accessible:
+            display_name = f"{self.name} (inaccessible)"
+        elif self.unflashed:
+            display_name = f"Unflashed {self.name}"
+        elif self.serial is not None:
+            display_name = f"{self.name} ({self.serial})"
+        else:
+            display_name = f"{self.name}"
+        return display_name
+
     def __str__(self) -> str:
-        return self.name
+        serial_str = "?" if self.serial is None else self.serial
+        return f"{self.name}: serial={serial_str}, VID=0x{self.vid:04x}, PID=0x{self.pid:04x}"
 
 
-_USB_IDS = [  # (vid, pid, 'model number')
-    (0x0483, 0xA41D, "Unflashed XC120"),
-    (0x0483, 0xA42C, "Unflashed XC120"),
-    (0x0483, 0xA42D, "XC120"),
+_USB_IDS = [  # (vid, pid, 'model number', 'Unflashed')
+    (0x0483, 0xA41D, "XC120", True),
+    (0x0483, 0xA42C, "XC120", True),
+    (0x0483, 0xA42D, "XC120", False),
 ]
 
 
@@ -137,7 +151,7 @@ def tag_serial_ports_objects(port_infos):
 
         match = re.search(PRODUCT_REGEX, desc)
         if match is None:
-            for vid, pid, model_number in _USB_IDS:
+            for vid, pid, model_number, _ in _USB_IDS:
                 if port_object.vid == vid and port_object.pid == pid:
                     port_tag_tuples.append((port_object, model_number))
                     break
@@ -237,37 +251,55 @@ def get_usb_devices(only_accessible=False):
 
     if WinUsbPy is not None:
         winusbpy = WinUsbPy()
-        all_usb_devices = winusbpy.list_usb_devices(deviceinterface=True, present=True)
-
-        for name, path in all_usb_devices.items():
-            pattern = r"(.*)#vid_(?P<vid>\w+)&pid_(?P<pid>\w+)(.*)"
-            match = re.fullmatch(pattern, path)
-            groups = match.groupdict()
-            v = int(f"0x{groups['vid']}", 16)
-            p = int(f"0x{groups['pid']}", 16)
-            for vid, pid, model_name in _USB_IDS:
-                if v == vid and p == pid:
-                    usb_devices.append(USBDevice(vid=v, pid=p, serial=None, name=model_name))
+        device_list = winusbpy.find_all_devices()
+        for device in device_list:
+            device_vid = device["vid"]
+            device_pid = device["pid"]
+            serial_number = device["serial"]
+            for vid, pid, model_name, unflashed in _USB_IDS:
+                if device_vid == vid and device_pid == pid:
+                    usb_devices.append(
+                        USBDevice(
+                            vid=device_vid,
+                            pid=device_pid,
+                            serial=serial_number,
+                            name=model_name,
+                            unflashed=unflashed,
+                        )
+                    )
     else:
         pyusbcomm = PyUsbComm()
-        for device_vid, device_pid in pyusbcomm.iterate_devices():
-            for vid, pid, model_name in _USB_IDS:
+        for device_vid, device_pid, serial_number in pyusbcomm.iterate_devices():
+            for vid, pid, model_name, unflashed in _USB_IDS:
                 if device_vid == vid and device_pid == pid:
                     device_name = model_name
                     accessible = pyusbcomm.is_accessible(vid, pid)
-                    if not accessible:
-                        device_name = f"{device_name} (inaccessible)"
-
                     if only_accessible and not accessible:
                         continue
 
                     usb_devices.append(
-                        USBDevice(vid=device_vid, pid=device_pid, serial=None, name=device_name)
+                        USBDevice(
+                            vid=device_vid,
+                            pid=device_pid,
+                            serial=serial_number,
+                            name=device_name,
+                            accessible=accessible,
+                            unflashed=unflashed,
+                        )
                     )
 
     return usb_devices
 
 
+def get_usb_device_by_serial(serial, only_accessible=False):
+    usb_devices = get_usb_devices(only_accessible=only_accessible)
+    if serial is not None:
+        for device in usb_devices:
+            if serial == device.serial:
+                return device
+    raise ValueError(f"Could not find usb device with serial number '{serial}'")
+
+
 def color_cycler(i=0):
     category10 = [
         "#1f77b4",
